import React, { useEffect, useState } from "react";
import { Box, Heading, Button, Image, Stack, Text } from "grommet";
import LoadingWrapper from "./LoadingWrapper";
import { ChapterAdd } from "grommet-icons";
import WindowsImage from "../img_temp/windows.jpg";
import UbuntuImage from "../img_temp/ubuntu.jpg";

const mockData = [
  {
    name: "Software validation homework",
    os: "windows",
    system: "Windows 10"
  },
  {
    name: "Nginx webserver",
    os: "ubuntu",
    system: "Ubuntu 18.04"
  },
  {
    name: "Matlab simulation environment",
    os: "windows",
    system: "Windows 10"
  }
];

const TemplateView = () => {
  const [data, setData] = useState([]);
  const [isLoading, setIsLoading] = useState(true);

  useEffect(() => {
    setIsLoading(true);
    fetch("http://vm.niif.cloud.bme.hu:20778/api/v1/instances/")
      .then(response => response.json())
      .then(json => setData(json))
      .then(() => setIsLoading(false));
  }, []);

  return (
    <LoadingWrapper loading={isLoading}>
      <Box direction="column" margin="small" justify="evenly" align="center">
        <Heading margin="small">Templates</Heading>
        <Button
          icon={<ChapterAdd />}
          label="Create a new template"
          size="xlarge"
          primary
          color="darkbrand"
        />
      </Box>
      <Box direction="row" wrap justify="evenly">
        {mockData.map(e => (
          <Box margin="small">
            <Stack>
              {e.os === "windows" ? (
                <Image
                  src={WindowsImage}
                  fit="contain"
                  style={{ height: "250px" }}
                />
              ) : (
                <Image
                  src={UbuntuImage}
                  fit="contain"
                  style={{ height: "250px" }}
                />
              )}
              <Box background="#666666CC">
                <Text margin="small">{e.name}</Text>
              </Box>
            </Stack>
          </Box>
        ))}
      </Box>
    </LoadingWrapper>
  );
};

export default TemplateView;
